@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  Alleyoop
- *  Copyright (C) 2003-2006 Jeffrey Stedfast
+ *  Copyright (C) 2003-2009 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ typedef struct _ElfSection {
 
 typedef struct _ElfSymbol {
 	struct _ElfSymbol *next;
-	struct _ElfSection *sect;
+	ElfSection *sect;
 	const char *name;
 	ElfDesc *elfd;
 	size_t index;
