@@ -43,6 +43,7 @@
 #endif
 #define TRACE_CHILDREN_KEY   "/apps/alleyoop/valgrind/general/trace-children"
 #define TRACK_FDS_KEY        "/apps/alleyoop/valgrind/general/track-fds"
+#define TRACK_ORIGINS_KEY    "/apps/alleyoop/valgrind/general/track-origins"
 #define TIME_STAMP_KEY       "/apps/alleyoop/valgrind/general/time-stamp"
 #define RUN_LIBC_FREERES_KEY "/apps/alleyoop/valgrind/general/run-libc-freeres"
 #define SUPPRESSIONS_KEY     "/apps/alleyoop/valgrind/general/suppressions"
@@ -228,6 +229,14 @@ vg_general_prefs_init (VgGeneralPrefs *prefs)
 	gtk_widget_show (widget);
 	gtk_box_pack_start ((GtkBox *) vbox, widget, FALSE, FALSE, 0);
 	
+	bool = gconf_client_get_bool (gconf, TRACK_ORIGINS_KEY, NULL);
+	widget = gtk_check_button_new_with_label (_("Track rigins of undefined values"));
+	g_signal_connect (widget, "toggled", G_CALLBACK (toggle_button_toggled), TRACK_ORIGINS_KEY);
+	gtk_toggle_button_set_active ((GtkToggleButton *) widget, bool);
+	prefs->track_origins = (GtkToggleButton *) widget;
+	gtk_widget_show (widget);
+	gtk_box_pack_start ((GtkBox *) vbox, widget, FALSE, FALSE, 0);
+	
 	bool = gconf_client_get_bool (gconf, TIME_STAMP_KEY, NULL);
 	widget = gtk_check_button_new_with_label (_("Add time stamps to log messages"));
 	g_signal_connect (widget, "toggled", G_CALLBACK (toggle_button_toggled), TIME_STAMP_KEY);
@@ -313,13 +322,14 @@ static struct {
 	int dval;
 } general_args[] = {
 	{ DEMANGLE_KEY,         "--demangle",         NULL, ARG_TYPE_BOOL,   1 },
-	{ NUM_CALLERS_KEY,      "--num-callers",      NULL, ARG_TYPE_INT,    4 },
+	{ NUM_CALLERS_KEY,      "--num-callers",      NULL, ARG_TYPE_INT,    0 },
 	{ ERROR_LIMIT_KEY,      "--error-limit",      NULL, ARG_TYPE_BOOL,   1 },
 #ifdef SLOPPY_MALLOC
 	{ SLOPPY_MALLOC_KEY,    "--sloppy-malloc",    NULL, ARG_TYPE_BOOL,   0 },
 #endif
 	{ TRACE_CHILDREN_KEY,   "--trace-children",   NULL, ARG_TYPE_BOOL,   0 },
 	{ TRACK_FDS_KEY,        "--track-fds",        NULL, ARG_TYPE_BOOL,   0 },
+	{ TRACK_ORIGINS_KEY,    "--track-origins",    NULL, ARG_TYPE_BOOL,   0 },
 	{ TIME_STAMP_KEY,       "--time-stamp",       NULL, ARG_TYPE_BOOL,   0 },
 	{ RUN_LIBC_FREERES_KEY, "--run-libc-freeres", NULL, ARG_TYPE_BOOL,   0 },
 	{ SUPPRESSIONS_KEY,     "--suppressions",     NULL, ARG_TYPE_STRING, 0 },
@@ -334,7 +344,7 @@ general_prefs_get_argv (VgToolPrefs *prefs, const char *tool, GPtrArray *argv)
 	
 	gconf = gconf_client_get_default ();
 	
-	g_ptr_array_add (argv, "--alignment=8");
+	/*g_ptr_array_add (argv, "--alignment=8");*/
 	
 	for (i = 0; i < G_N_ELEMENTS (general_args); i++) {
 		const char *arg = general_args[i].arg;
@@ -361,7 +371,7 @@ general_prefs_get_argv (VgToolPrefs *prefs, const char *tool, GPtrArray *argv)
 				continue;
 			}
 			
-			if (general_args[i].key == SUPPRESSIONS_KEY &&
+			if (!strcmp (general_args[i].key, SUPPRESSIONS_KEY) &&
 			    (stat (str, &st) == -1 || !S_ISREG (st.st_mode))) {
 				general_args[i].buf = NULL;
 				g_free (str);
