@@ -23,6 +23,7 @@
 #endif
 
 #include <string.h>
+#include <stdlib.h>
 
 #include <gconf/gconf-client.h>
 #include <libgnome/gnome-i18n.h>
@@ -30,10 +31,10 @@
 #include "vghelgrindprefs.h"
 
 
-#define HAPPENS_BEFORE_KEY    "/apps/alleyoop/valgrind/helgrind/happens_before"
-#define ENABLE_TRACE_ADDR_KEY "/apps/alleyoop/valgrind/helgrind/enable_trace_addr"
-#define TRACE_ADDR_KEY        "/apps/alleyoop/valgrind/helgrind/trace_addr"
-#define TRACE_LEVEL_KEY       "/apps/alleyoop/valgrind/helgrind/trace_level"
+#define HAPPENS_BEFORE_KEY    "/apps/alleyoop/valgrind/helgrind/happens-before"
+#define ENABLE_TRACE_ADDR_KEY "/apps/alleyoop/valgrind/helgrind/enable-trace-addr"
+#define TRACE_ADDR_KEY        "/apps/alleyoop/valgrind/helgrind/trace-addr"
+#define TRACE_LEVEL_KEY       "/apps/alleyoop/valgrind/helgrind/trace-level"
 
 static void vg_helgrind_prefs_class_init (VgHelgrindPrefsClass *klass);
 static void vg_helgrind_prefs_init (VgHelgrindPrefs *prefs);
@@ -115,7 +116,7 @@ decode_hex_value (const char *text)
 	if (inend == text)
 		return NULL;
 	
-	return g_strdup_printf ("0x%X", retval);
+	return g_strdup_printf ("0x%lX", retval);
 }
 
 static gboolean
@@ -152,11 +153,18 @@ menu_item_activated (GtkMenuItem *item, const char *key)
 {
 	GConfClient *gconf;
 	const char *str;
+	int val;
 	
 	gconf = gconf_client_get_default ();
 	
 	str = g_object_get_data ((GObject *) item, "value");
-	gconf_client_set_string (gconf, key, str, NULL);
+	
+	if (!strcmp (key, TRACE_LEVEL_KEY)) {
+		val = strtol (str, NULL, 10);
+		gconf_client_set_int (gconf, key, val, NULL);
+	} else {
+		gconf_client_set_string (gconf, key, str, NULL);
+	}
 	
 	g_object_unref (gconf);
 }
@@ -168,11 +176,16 @@ static GtkWidget *
 option_menu_new (GConfClient *gconf, const char **opts, int nopts, const char *key)
 {
 	GtkWidget *omenu, *menu, *item;
-	int history = 0;
+	int history, i;
 	char *str;
-	int i;
 	
-	str = gconf_client_get_string (gconf, key, NULL);
+	if (!strcmp (key, TRACE_LEVEL_KEY)) {
+		history = gconf_client_get_int (gconf, key, NULL);
+		str = NULL;
+	} else {
+		str = gconf_client_get_string (gconf, key, NULL);
+		history = 0;
+	}
 	
 	menu = gtk_menu_new ();
 	for (i = 0; i < nopts; i++) {
@@ -279,15 +292,21 @@ helgrind_prefs_apply (VgToolPrefs *prefs)
 	;
 }
 
+enum {
+	ARG_TYPE_INT,
+	ARG_TYPE_STRING
+};
+
 static struct {
 	const char *key;
 	const char *arg;
 	gboolean depends;
 	char *buf;
+	int type;
 } helgrind_args[] = {
-	{ HAPPENS_BEFORE_KEY,   "--happens-before",   FALSE, NULL },
-	{ TRACE_ADDR_KEY,       "--trace-addr",       TRUE,  NULL },
-	{ TRACE_LEVEL_KEY,      "--trace-level",      TRUE,  NULL },
+	{ HAPPENS_BEFORE_KEY, "--happens-before", FALSE, NULL, ARG_TYPE_STRING },
+	{ TRACE_ADDR_KEY,     "--trace-addr",     TRUE,  NULL, ARG_TYPE_STRING },
+	{ TRACE_LEVEL_KEY,    "--trace-level",    TRUE,  NULL, ARG_TYPE_INT    },
 };
 
 static void
@@ -296,6 +315,7 @@ helgrind_prefs_get_argv (VgToolPrefs *prefs, const char *tool, GPtrArray *argv)
 	gboolean enable_trace_addr;
 	GConfClient *gconf;
 	char *str;
+	int val;
 	int i;
 	
 	gconf = gconf_client_get_default ();
@@ -312,17 +332,22 @@ helgrind_prefs_get_argv (VgToolPrefs *prefs, const char *tool, GPtrArray *argv)
 		if (helgrind_args[i].depends && !enable_trace_addr)
 			continue;
 		
-		if (!(str = gconf_client_get_string (gconf, key, NULL)) || *str == '\0') {
-			if (key == TRACE_ADDR_KEY)
-				enable_trace_addr = FALSE;
+		if (helgrind_args[i].type == ARG_TYPE_STRING) {
+			if (!(str = gconf_client_get_string (gconf, key, NULL)) || *str == '\0') {
+				if (!strcmp (key, TRACE_ADDR_KEY))
+					enable_trace_addr = FALSE;
+				
+				g_free (str);
+				continue;
+			}
 			
+			helgrind_args[i].buf = g_strdup_printf ("%s=%s", arg, str);
 			g_free (str);
-			continue;
+		} else if (helgrind_args[i].type == ARG_TYPE_INT) {
+			val = gconf_client_get_int (gconf, key, NULL);
+			helgrind_args[i].buf = g_strdup_printf ("%s=%d", arg, val);
 		}
 		
-		helgrind_args[i].buf = g_strdup_printf ("%s=%s", arg, str);
-		g_free (str);
-		
 		g_ptr_array_add (argv, helgrind_args[i].buf);
 	}
 	
