@@ -23,6 +23,7 @@
 #endif
 
 #include <string.h>
+#include <stdlib.h>
 #include <limits.h>
 #include <ctype.h>
 
@@ -36,12 +37,12 @@
 #define SHOW_REACHABLE_KEY         "/apps/alleyoop/valgrind/memcheck/show-reachable"
 #define LEAK_RESOLUTION_KEY        "/apps/alleyoop/valgrind/memcheck/leak-resolution"
 #define FREELIST_VOL_KEY           "/apps/alleyoop/valgrind/memcheck/freelist-vol"
-//#define ENABLE_IGNORE_RANGES_KEY   "/apps/alleyoop/valgrind/memcheck/enable_ignore_ranges"
-#define IGNORE_RANGES_KEY          "/apps/alleyoop/valgrind/memcheck/ignore_ranges"
-//#define ENABLE_MALLOC_FILL_KEY     "/apps/alleyoop/valgrind/memcheck/enable_malloc_fill"
-#define MALLOC_FILL_KEY            "/apps/alleyoop/valgrind/memcheck/malloc_fill"
-//#define ENABLE_FREE_FILL_KEY       "/apps/alleyoop/valgrind/memcheck/enable_free_fill"
-#define FREE_FILL_KEY              "/apps/alleyoop/valgrind/memcheck/free_fill"
+//#define ENABLE_IGNORE_RANGES_KEY   "/apps/alleyoop/valgrind/memcheck/enable-ignore-ranges"
+#define IGNORE_RANGES_KEY          "/apps/alleyoop/valgrind/memcheck/ignore-ranges"
+//#define ENABLE_MALLOC_FILL_KEY     "/apps/alleyoop/valgrind/memcheck/enable-malloc-fill"
+#define MALLOC_FILL_KEY            "/apps/alleyoop/valgrind/memcheck/malloc-fill"
+//#define ENABLE_FREE_FILL_KEY       "/apps/alleyoop/valgrind/memcheck/enable-free-fill"
+#define FREE_FILL_KEY              "/apps/alleyoop/valgrind/memcheck/free-fill"
 #define WORKAROUND_GCC296_BUGS_KEY "/apps/alleyoop/valgrind/memcheck/workaround-gcc296-bugs"
 
 static void vg_memcheck_prefs_class_init (VgMemcheckPrefsClass *klass);
@@ -157,7 +158,7 @@ decode_hex_range (const char *text)
 		inptr++;
 	
 	while (*inptr) {
-		retval = strtoul (inptr, &inend, 16);
+		retval = strtoul (inptr, (char **) &inend, 16);
 		if (inend == inptr)
 			break;
 		
@@ -203,7 +204,7 @@ decode_hex_value (const char *text)
 	unsigned long int retval;
 	const char *inend;
 	
-	retval = strtoul (text, &inend, 16);
+	retval = strtoul (text, (char **) &inend, 16);
 	if (inend == text)
 		return NULL;
 	
@@ -220,7 +221,7 @@ entry_focus_out (GtkEntry *entry, GdkEventFocus *event, const char *key)
 	gconf = gconf_client_get_default ();
 	
 	if ((text = gtk_entry_get_text (entry))) {
-		if (key == IGNORE_RANGES_KEY)
+		if (!strcmp (key, IGNORE_RANGES_KEY))
 			str = decode_hex_range (text);
 		else
 			str = decode_hex_value (text);
